@@ -1,9 +1,9 @@
 package Data::Sah::Filter::perl::Unix::convert_unix_group_to_gid;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-27'; # DATE
+our $DATE = '2020-06-13'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,7 +26,7 @@ sub filter {
 
     $res->{expr_filter} = join(
         "",
-        "do { my \$tmp = $dt; if (\$tmp !~ /\\A[0-9]+\\z/) { my \@gr = getgrnam(\$tmp); return [\"Unknown Unix user '\$tmp'\", \$tmp] unless \@gr; return [undef, \$gr[2]] } [undef, \$tmp] }",
+        "do { my \$tmp = $dt; if (\$tmp !~ /\\A[0-9]+\\z/) { my \@gr = getgrnam(\$tmp); \@gr ? [undef, \$gr[2]] : [\"Unknown Unix user '\$tmp'\", \$tmp] } else { [undef, \$tmp] } }",
     );
 
     $res;
@@ -47,7 +47,7 @@ Data::Sah::Filter::perl::Unix::convert_unix_group_to_gid
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::Filter::perl::Unix::convert_unix_group_to_gid (from Perl distribution Sah-Schemas-Unix), released on 2020-05-27.
+This document describes version 0.012 of Data::Sah::Filter::perl::Unix::convert_unix_group_to_gid (from Perl distribution Sah-Schemas-Unix), released on 2020-06-13.
 
 =for Pod::Coverage ^(meta|filter)$
 
