@@ -1,9 +1,9 @@
 package Data::Sah::Filter::perl::Unix::try_convert_gid_to_unix_group;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-27'; # DATE
+our $DATE = '2020-06-13'; # DATE
 our $DIST = 'Sah-Schemas-Unix'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,7 +25,7 @@ sub filter {
 
     $res->{expr_filter} = join(
         "",
-        "do { my \$tmp = $dt; if (\$tmp =~ /\\A[0-9]+\\z/) { my \@gr = getgrgid(\$tmp); return \@gr ? \$gr[0] : \$tmp } \$tmp }",
+        "do { my \$tmp = $dt; if (\$tmp =~ /\\A[0-9]+\\z/) { my \@gr = getgrgid(\$tmp); \@gr ? \$gr[0] : \$tmp } else { \$tmp } }",
     );
 
     $res;
@@ -46,7 +46,7 @@ Data::Sah::Filter::perl::Unix::try_convert_gid_to_unix_group
 
 =head1 VERSION
 
-This document describes version 0.011 of Data::Sah::Filter::perl::Unix::try_convert_gid_to_unix_group (from Perl distribution Sah-Schemas-Unix), released on 2020-05-27.
+This document describes version 0.012 of Data::Sah::Filter::perl::Unix::try_convert_gid_to_unix_group (from Perl distribution Sah-Schemas-Unix), released on 2020-06-13.
 
 =for Pod::Coverage ^(meta|filter)$
 
